Recluse

Author: L. Amber Wilcox-O'Hearn

Contact: amber@cs.toronto.edu

Released under the GNU AFFERO GENERAL PUBLIC LICENSE, see COPYING file for details.

==============
Introduction
==============

Recluse (Reproducible Experimentation for Computational Linguistics Use) is a set of tools for running computational linguistics experiments reproducibly.

This first version contains 

* utils, which has a function for reading and writing unicode with regular or compressed text.
* article_randomiser, which reproducibly randomly divides a corpus into training, development, and test sets.




